@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -19,6 +19,7 @@ import os
 import shutil
 import subprocess
 from distutils import ccompiler
+from distutils.util import get_platform
 
 from .utils import base_cache_folder, create_folder_if_not_exists, run_in_folder
 
@@ -68,7 +69,7 @@ def compile_if_needed(target_folder):
 
 def install_lsoda_fast_if_needed(lsoda_root_folder=None):
     if lsoda_root_folder is None:
-        lsoda_root_folder = os.path.join(base_cache_folder(), "sympy2c")
+        lsoda_root_folder = os.path.join(base_cache_folder(), "sympy2c", get_platform())
 
     target_folder = os.path.join(lsoda_root_folder, "lsoda_fast")
     create_folder_if_not_exists(target_folder)
