@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -26,6 +26,7 @@ import threading
 import time
 import warnings
 from contextlib import contextmanager
+from distutils.util import get_platform
 from functools import partial
 
 from .build_gsl import install_gsl_if_needed
@@ -61,7 +62,7 @@ def compile_if_needed_and_load(
     cache_folder = base_cache_folder()
 
     if gsl_root is None:
-        gsl_root = os.path.join(cache_folder, "gsl")
+        gsl_root = os.path.join(cache_folder, "gsl", get_platform())
     if not os.path.exists(gsl_root) or not os.listdir(gsl_root):
         download_folder = tempfile.mkdtemp()
         install_gsl_if_needed(download_folder, gsl_root)
@@ -88,7 +89,7 @@ def compile_if_needed_and_load(
 
 
 def compile_libf2c():
-    folder = os.path.join(base_cache_folder(), "libf2c")
+    folder = os.path.join(base_cache_folder(), "libf2c", get_platform())
     lib_path = os.path.join(folder, "libf2c.a")
     if os.path.exists(lib_path):
         return lib_path
