@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -17,7 +17,7 @@
 import sys
 from functools import partial
 
-from .compiler import build_folder, compile_if_needed_and_load, LoadedModule
+from .compiler import LoadedModule, build_folder, compile_if_needed_and_load
 from .create_curry_class import create_interface_onary
 from .expressions import Max, Min, isnan
 from .function import Alias, Function, function_wrapper_factory
