@@ -1,6 +1,6 @@
 # This file is part of sympy2c.
 #
-# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# Copyright (C) 2013-2022 ETH Zurich, Institute for Particle and Astrophysics and SIS
 # ID.
 #
 # This program is free software: you can redistribute it and/or modify it under the
@@ -14,6 +14,7 @@
 # You should have received a copy of the GNU General Public License along with this
 # program.  If not, see <http://www.gnu.org/licenses/>.
 
+import distutils.util
 import functools
 import hashlib
 import os
@@ -26,6 +27,22 @@ from sympy import Symbol
 from .version import __version__
 
 
+import subprocess
+import os
+import platform
+
+
+def get_platform():
+    platform = distutils.util.get_platform()
+    os, version, machine = platform.split("-")
+    if os != "macosx":
+        return platform
+    python_exe_path = subprocess.check_output(["which", "python"], text=True)
+    file_type = subprocess.check_output(["file", python_exe_path], text=True)
+    machine = file_type.split(" ")[-1]
+    return "-".join([os, version, machine])
+
+
 def create_folder_if_not_exists(folder):
     if not os.path.exists(folder):
         try:
@@ -119,5 +136,7 @@ def sympy2c_cache_folder():
     numpy_version = "_".join(numpy.__version__.split("."))
     sympy_version = "_".join(map(str, __version__))
     return os.path.join(
-        base_cache_folder(), "sympy2c", sympy_version + "__np_" + numpy_version
+        base_cache_folder(),
+        "sympy2c",
+        sympy_version + "__np_" + numpy_version + "__" + get_platform(),
     )
